{
  flake,
  pkgs,
  ...
}:
let
  inherit (flake.config.people) user0;
  inherit (flake.config.people.users.${user0}) email;
in
{
  services.espanso = {
    enable = true;
    configs = {
      default = {
        pre_paste_delay = 0;
        show_notifications = false;
      };
    };
    package = pkgs.espanso-wayland;
    matches = {
      base = {
        matches = [
          {
            trigger = ":up";
            replace = "↑";
          }
          {
            trigger = ":down";
            replace = "↓";
          }
          {
            trigger = ":left";
            replace = "←";
          }
          {
            trigger = ":right";
            replace = "→";
          }
          {
            trigger = ":neg";
            replace = "¬";
          }
          {
            trigger = ":conj";
            replace = "∧";
          }
          {
            trigger = ":disj";
            replace = "∨";
          }
          {
            trigger = ":imp";
            replace = "→";
          }
          {
            trigger = ":bicon";
            replace = "↔";
          }
          {
            trigger = ":forall";
            replace = "∀";
          }
          {
            trigger = ":exist";
            replace = "∃";
          }
          {
            trigger = ":therefore";
            replace = "∴";
          }
          {
            trigger = ":delta";
            replace = "Δ";
          }
          {
            trigger = ":emdash";
            replace = "—";
          }
          {
            trigger = ":glp";
            replace = "GLP-1RA";
          }
          {
            trigger = ":degree";
            replace = "°";
          }
          {
            trigger = ":ss1";
            replace = "¹";
          }
          {
            trigger = ":ss2";
            replace = "²";
          }
          {
            trigger = ":ss3";
            replace = "³";
          }
          {
            trigger = ":ss4";
            replace = "⁴";
          }
          {
            trigger = ":ss5";
            replace = "⁵";
          }
          {
            trigger = ":ss6";
            replace = "⁶";
          }
          {
            trigger = ":ss7";
            replace = "⁷";
          }
          {
            trigger = ":ss8";
            replace = "⁸";
          }
          {
            trigger = ":ss9";
            replace = "⁹";
          }
          {
            trigger = ":ss0";
            replace = "⁰";
          }
          {
            trigger = ":ntt";
            replace = ''
              World A) Animals farmed for food.
              World B) Humans farmed for food.

              All else equal, what is true of world A that is untrue of world B, that if made true of world B, would make world B permissible?'';
          }
          {
            trigger = ":dotfiles";
            replace = "https://gitlab.com/upRootNutrition/dotfiles";
          }
          {
            trigger = ":website";
            replace = "https://uprootnutrition.com";
          }
          {
            trigger = ":mail0";
            replace = email.address0;
          }
          {
            trigger = ":mail1";
            replace = email.address2;
          }
        ];
      };
      global_vars = {
        global_vars = [
          {
            name = "currentdate";
            type = "date";
            params = {
              format = "%d/%m/%Y";
            };
          }
          {
            name = "currenttime";
            type = "date";
            params = {
              format = "%R";
            };
          }
        ];
      };
    };
  };
}
